@@ -11,9 +11,7 @@
 // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 // See the License for the specific language governing permissions and
 // limitations under the License.
-mod fs;
 mod ops;
-mod s3;
 
 use criterion::criterion_group;
 use criterion::criterion_main;
