@@ -12,27 +12,30 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+use std::fmt::Debug;
 use std::sync::Arc;
 
 use async_trait::async_trait;
 
 use crate::error::Result;
+use crate::object::BoxedObjectStream;
 use crate::object::Metadata;
 use crate::ops::OpDelete;
+use crate::ops::OpList;
 use crate::ops::OpRead;
 use crate::ops::OpStat;
 use crate::ops::OpWrite;
-use crate::BoxedAsyncRead;
+use crate::BoxedAsyncReader;
 
 #[async_trait]
-pub trait Accessor: Send + Sync {
+pub trait Accessor: Send + Sync + Debug {
     /// Read data from the underlying storage into input writer.
-    async fn read(&self, args: &OpRead) -> Result<BoxedAsyncRead> {
+    async fn read(&self, args: &OpRead) -> Result<BoxedAsyncReader> {
         let _ = args;
         unimplemented!()
     }
     /// Write data from input reader to the underlying storage.
-    async fn write(&self, r: BoxedAsyncRead, args: &OpWrite) -> Result<usize> {
+    async fn write(&self, r: BoxedAsyncReader, args: &OpWrite) -> Result<usize> {
         let (_, _) = (r, args);
         unimplemented!()
     }
@@ -51,16 +54,21 @@ pub trait Accessor: Send + Sync {
         let _ = args;
         unimplemented!()
     }
+
+    async fn list(&self, args: &OpList) -> Result<BoxedObjectStream> {
+        let _ = args;
+        unimplemented!()
+    }
 }
 
 /// All functions in `Accessor` only requires `&self`, so it's safe to implement
 /// `Accessor` for `Arc<dyn Accessor>`.
 #[async_trait]
 impl<T: Accessor> Accessor for Arc<T> {
-    async fn read(&self, args: &OpRead) -> Result<BoxedAsyncRead> {
+    async fn read(&self, args: &OpRead) -> Result<BoxedAsyncReader> {
         self.as_ref().read(args).await
     }
-    async fn write(&self, r: BoxedAsyncRead, args: &OpWrite) -> Result<usize> {
+    async fn write(&self, r: BoxedAsyncReader, args: &OpWrite) -> Result<usize> {
         self.as_ref().write(r, args).await
     }
     async fn stat(&self, args: &OpStat) -> Result<Metadata> {
@@ -69,4 +77,7 @@ impl<T: Accessor> Accessor for Arc<T> {
     async fn delete(&self, args: &OpDelete) -> Result<()> {
         self.as_ref().delete(args).await
     }
+    async fn list(&self, args: &OpList) -> Result<BoxedObjectStream> {
+        self.as_ref().list(args).await
+    }
 }
