@@ -15,7 +15,7 @@ mod accessor;
 pub use accessor::Accessor;
 
 mod io;
-pub use io::BoxedAsyncRead;
+pub use io::BoxedAsyncReader;
 pub use io::Reader;
 pub use io::Writer;
 
@@ -28,6 +28,8 @@ pub use operator::Operator;
 mod object;
 pub use object::Metadata;
 pub use object::Object;
+pub use object::ObjectMode;
+pub use object::ObjectStream;
 
 mod scheme;
 pub use scheme::Scheme;
@@ -38,3 +40,6 @@ pub mod readers;
 
 pub mod ops;
 pub mod services;
+
+#[cfg(test)]
+pub mod tests;
